.trays{
  display: inline-block;
  position: relative;
  height: 20px;
  width: 20px;
  background-size: 20px 20px;
  vertical-align: middle;
  margin-left: 20px;
  }
  .trays__dropdown{
    position: absolute;
    top: 20px;
    left: -10px;
    min-width: 300px;
    background: #fff;
    display: none;
    padding: 10px;
    z-index: 20;
    }
  .trays__add{
    background: none;
    outline: none;
    border: none;
    font-weight: bold;
    display: inline-block;
    cursor: pointer;
    /* Folder by Simple Icons from The Noun Project, published under CC-BY */
    background: url(../images/folder.svg) no-repeat top left;
    background-size: 20px;
    width:20px;
    height: 20px;
    }
  .trays:hover .trays__dropdown{
    display: block;
    }
  .trays:hover .trays__add{
    /* Folder by Simple Icons from The Noun Project, published under CC-BY */
    background-image: url(../images/folder-add.svg);
    }
  .trays__tray{
    display: inline-block;
    position: relative;
    color: #fff;
    background-color: #5aa;
    padding-left: 5px;
    cursor: default;
    line-height: 1em;
    border-radius: 3px 10px 10px 3px;
    margin-bottom: 4px;
    margin-right: 10px;
    }
    .trays__tray a{
      color: inherit;
      text-decoration: none;
      }
    .trays__tray a:last-child{
      display: inline-block;
      padding: 4px 0;
      }
      .trays__tray a:last-child:after{
        content: "•";
        padding: 0 6px;
        }
  .trays__tray__remove{
    background: none;
    outline: none;
    border: none;
    border-left: 1px solid #fff;
    cursor: pointer;
    color: inherit;
    padding: 0 4px;
    margin-left: 4px;
    line-height: 1em;
    }
  .trays__comment{
    position: absolute;
    display: none;
    top: 24px;
    left: 0px;
    background: rgba(255, 255, 255, 0.9);
    color: #555;
    min-width: 200px;
    padding: 4px;
    z-index: 5;
    }
    .trays__comment-hellip:hover .trays__comment{
      display: block;
      }
    .trays__comment-hellip{
      display: inline-block;
      border-left: 1px solid #fff;
      padding: 0 0 0 4px;
      margin-left: 4px;
      cursor: help;
      }
    .trays__comment-hellip:before{
      content: "?";
      }
.tray__remove{
  background: /* fixed */ url(../images/reset.gif) no-repeat left;
  padding-left: 12px;
  color: #990000;
  text-decoration: none;
  cursor: pointer;
  }

.tray0  { background-color: rgb(182, 207, 245); color: rgb(13, 52, 114);}
.tray1  { background-color: rgb(66, 214, 146); color: rgb(9, 66, 40);}
.tray2  { background-color: rgb(246, 145, 178); color: rgb(153, 74, 100);}
.tray3  { background-color: rgb(255, 200, 175); color: rgb(122, 46, 11);}
.tray4  { background-color: rgb(242, 178, 168); color: rgb(138, 28, 10);}
.tray5  { background-color: rgb(255, 173, 70); color: rgb(255, 255, 255);}
.tray6  { background-color: rgb(162, 220, 193); color: rgb(4, 80, 46);}
.tray7  { background-color: rgb(185, 154, 255); color: rgb(255, 255, 255);}
.tray8  { background-color: rgb(253, 237, 193); color: rgb(104, 78, 7);}
.tray9  { background-color: rgb(251, 76, 47); color: rgb(255, 255, 255);}
.tray10 { background-color: rgb(251, 211, 224); color: rgb(113, 26, 54);}
.tray11 { background-color: rgb(204, 166, 172); color: rgb(255, 255, 255);}
.tray12 { background-color: rgb(255, 117, 55); color: rgb(255, 255, 255);}
.tray13 { background-color: rgb(45, 162, 187); color: rgb(255, 255, 255);}
.tray14 { background-color: rgb(251, 233, 131); color: rgb(89, 76, 5);}
.tray15 { background-color: rgb(194, 194, 194); color: rgb(255, 255, 255);}
.tray26 { background-color: rgb(227, 215, 255); color: rgb(61, 24, 142);}
.tray17 { background-color: rgb(73, 134, 231); color: rgb(255, 255, 255);}
.tray18 { background-color: rgb(235, 219, 222); color: rgb(102, 46, 55);}
.tray19 { background-color: rgb(255, 222, 181); color: rgb(122, 71, 6);}
.tray20 { background-color: rgb(231, 231, 231); color: rgb(70, 70, 70);}
.tray21 { background-color: rgb(22, 167, 101); color: rgb(255, 255, 255);}
.tray22 { background-color: rgb(179, 239, 211); color: rgb(11, 79, 48);}
.tray23 { background-color: rgb(152, 215, 228); color: rgb(13, 59, 68);}

a.tray-count,
.tray-count{
  display: inline-block;
  width: 16px;
  height: 16px;
  line-height: 16px;
  margin-left: 5px;
  background: #fff;
  color: #7F8C8D;
  text-align: center;
  text-decoration: none;
  border-radius: 4px;
  }
