{% if field_val %}
<div class="init-block locked" data-block-name="locked-icon" title="Заблокировано пользователем {{ field_val['user'].name }}" data-guid="{{ field_val['guid'] }}" data-edit-session="{{ field_val['edit_session'] }}"></div>
{% endif %}
