<a data-wysihtml5-command="extrachars" class="btn">Специальные символы</a>
<div class="wysihtml5-dialog-place">
  <div class="wysihtml5-dialog" data-wysihtml5-dialog="extrachars"
    style="display: none; width: 230px; left: -110px">
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="—"
       class="wysihtml5-char">—</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="–"
       class="wysihtml5-char">–</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="±"
       class="wysihtml5-char">±</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="…"
       class="wysihtml5-char">…</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="«"
       class="wysihtml5-char">«</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="»"
       class="wysihtml5-char">»</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="©"
       class="wysihtml5-char">©</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="™"
       class="wysihtml5-char">™</a>
    <a data-wysihtml5-command="insertHTML" data-wysihtml5-command-value="&nbsp;"
       class="wysihtml5-char">неразрывный пробел</a>
    <!--br/>
    <a style="float: right" onclick="this.getParent('.wysihtml5-dialog').style.display = 'none'">Закрыть</a-->
  </div>
</div>
