.long-press-popup {
  position: fixed;
  bottom: 0;
  left: 0;
  right: 0;
  text-align: center;
  background: rgba(0, 0, 0, .8);
  padding-top: 20px;
  margin:0;
  font-size: 40px;
  display: none;
  z-index: 100;
}

.long-press-popup>li {
  display:inline-block;
  list-style: none;
  padding: 10px 34px;
  margin-right: 20px;
  margin-bottom: 20px;
  background: #000000;
  cursor:pointer;
  color: white;
  border: solid 4px black;
  border-radius: 12px;
}
.long-press-popup>.selected {
  border-color: white;
  -webkit-box-shadow: 0 0 18px rgba(255, 255, 255, 0.75);
  -moz-box-shadow:    0 0 18px rgba(255, 255, 255, 0.75);
  box-shadow:         0 0 18px rgba(255, 255, 255, 0.75);
}

.long-press-description {
  position: fixed;
  bottom: 5px;
  left: 0;
  right: 0;
  text-align: center;
  margin:0;
  font-size: 12px;
  display: none;
  z-index: 100;
  color: #fff;
  }

.long-press-description.show,
.long-press-popup.show {
  display: block;
  }
