.fieldset_buttons {
  overflow: hidden;
  padding: 0px;
  background: #7F8C8D;
  white-space: nowrap;
  }
  .fieldset_buttons .toolbar {
    display: inline-block;
    padding: 0px;
    background: #7F8C8D;
    }
    .fieldset_buttons .toolbar:after {
      content: "||";
      padding: 0 5px;
      color: #aaa;
      }
    .fieldset_buttons .toolbar:last-child:after {
      display: none;
      }
.fieldset_buttons .button{
  margin: 0;
  border-radius: 0;
  padding: 8px;
  white-space: nowrap;
  overflow: hidden;
  font-size: 11px;
  font-weight: normal;
  }
  .fieldset_buttons .button:after {
    display: none;
    }

.fieldset_buttons .toolbar .button+.button{
    display: none;
    }
.fieldset_buttons .toolbar.hover .button,
.fieldset_buttons .toolbar.active .button{
    display: inline-block;
    }
