.navigation {
    color: #ffffff;
    background: #5e676e;
    position: fixed;
    height: 38px;
    width: 100%;
    z-index: 4;
    top: 0;
    }

.navigation a {
    color: #ffffff;
}

.navigation .links {
    float: right;
    padding: 10px 20px;
    max-width: 250px;
    }
    .navigation .links .links__link{
        padding-left: 10px;
        }

.navigation>.menu {
  list-style: none;
  padding: 0 250px 0 0; /*should be equal to .navigation .links max-width*/
  margin: 0;
  position: absolute;
  bottom: 0px;
}

.navigation>.menu>li {
  display: inline-block;
  vertical-align: middle;
  padding: 8px 10px;
  margin: 0 2px;
  }
  .navigation .menu li {
  line-height: 22px;
  background: rgba(255,255,255,0.15);
  }

.navigation .menu li .stream-flag{
  padding-top: 0;
  padding-bottom: 0;
  }

.navigation .menu li:first-of-type {
  margin-left: 50px;
}

.navigation .menu li.active {
  background: #65a12b;
}

.navigation .menu .menu {
  display: none;
  position: absolute;
  top: 35px;
  z-index: 1000;
  background: #717b83;
  padding: 10px 0px;
  margin: 0;
  margin-left: -10px;
  overflow: hidden;
}

.navigation .menu .menu li {
  float: none;
  margin: 0;
  padding: 0;
}

.navigation .menu .menu li > span:first-child {
  padding-left: 10px;
  line-height: 200%;
}

.navigation .menu .menu li > a:first-child {
  padding-left: 10px;
  line-height: 200%;
}

.navigation .menu .menu li > a:last-of-type {
  padding-right: 10px;
}

.navigation .menu .menu .divided {
  margin-top: 5px;
  border-top: 1px solid #e3e6e8;
}

.navigation .menu .menu .menu {
  position: relative;
  padding: 0;
  margin: 0;
  top: 0;
}

.navigation .menu .menu .menu li > span:first-child {
  padding-left: 20px;
}

.navigation .menu .menu .menu li > a:first-child {
  padding-left: 20px;
}

.navigation .menu .create {
  padding: 0 5px;
  font-size: 14px;
  color: #fff;
  font-weight: bold;
  vertical-align: middle;
  text-decoration: none;
}

.navigation li:hover .menu {
  display: block;
}

