table.fieldlist {
  border-collapse: none;
  border-spacing: 0 10px;
}

table.fieldlist td a.remove {
  background: url(../images/reset.gif) no-repeat left;
  padding-left: 12px;
  color: #990000;
  text-decoration: none;
}

table.fieldlist td a.sort {
  text-decoration: none;
  font-weight: bold;
  font-size: 18px;
  padding: 0 4px;
}

table.fieldlist td a.sort:hover {
  background: #fefeca;
}

table.fieldlist tr:first-child>td>a.sort-up,
table.fieldlist tr:last-child>td>a.sort-down {
  visibility: hidden;
}

table.fieldlist table {
  margin-right: 10px;
}

.fieldlist-btns {
  background: #d1dec7;
  width: 1%;
}

tr.fieldlist-item>td {
  border: 1px solid #d1dec7;
  padding: 0;
}
