<a data-wysihtml5-command="insertImage" class="btn">Вставить изображение</a>
<div class="wysihtml5-dialog-place">
  <div class="wysihtml5-dialog" data-wysihtml5-dialog="insertImage" style="display: none;">
    <label>
      Ссылка на изображение:
      <input data-wysihtml5-dialog-field="src" value="http://" class="text">
    </label>
    <br/>
    <a data-wysihtml5-dialog-action="save">Применить</a>
    <!--a data-wysihtml5-dialog-action="cancel">Закрыть</a-->
  </div>
</div>
