.preview-width {
  display: inline-block;
  padding-left: 20px;
  white-space: nowrap;
  height: 25px;
  overflow: hidden;
  background: #fff;
  vertical-align: top;
  list-style: none;
  }
  .preview-width li{
    height: 25px;
    width: 25px;
    background: url(../images/desktop.svg) 50% 50% no-repeat #fff; 
    background-size: 20px;
    line-height: 25px;
    cursor: pointer;
    }
  .preview-width li.active{
    cursor: default;
    }
  .preview-width:hover{
    overflow: visible;
    }
  .preview-width li.active,
  .preview-width li:hover{
    background-size: 24px;
    }

    .preview-width li[data-device="laptop"]{
      /* Laptop by Alex AS from The Noun Project*/
      background-image: url(../images/laptop.svg);
    }
    .preview-width li[data-device="tablet"]{
      /*Tablet by Arthur Shlain from The Noun Project*/
      background-image: url(../images/tablet.svg);
    }
    .preview-width li[data-device="mobile"]{
      /*iPhone by Marwa Boukarim from The Noun Project*/
      background-image: url(../images/mobile.svg);
    }

