.button {
  background-color: #fdfdfd;
  background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #fdfdfd), color-stop(100%, #dadada));
  background-image: -webkit-linear-gradient(top, #fdfdfd, #dadada);
  background-image: -moz-linear-gradient(top, #fdfdfd, #dadada);
  background-image: -ms-linear-gradient(top, #fdfdfd, #dadada);
  background-image: -o-linear-gradient(top, #fdfdfd, #dadada);
  background-image: linear-gradient(top, #fdfdfd, #dadada);
  border-top: 1px solid #bababa;
  border-right: 1px solid #ababab;
  border-bottom: 1px solid #919191;
  border-left: 1px solid #ababab;
  border-radius: 13px;
  box-shadow: inset 0 1px 0 0 #e5e5e5;
  color: #445;
  font: 11px/1 "Lucida Grande", "Lucida Sans Unicode", "Lucida Sans", Geneva, Verdana, sans-serif;
  padding: 4px 10px;
  text-align: center;
  text-shadow: 1px 1px 1px #fff;
  text-decoration: none;
  position: relative;
  display: inline-block;
  margin: 2px;
  }
  .button:hover {
    background-color: #f3f3f3;
    background-image: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #f3f3f3), color-stop(100%, #d1d1d1));
    background-image: -webkit-linear-gradient(top, #f3f3f3, #d1d1d1);
    background-image: -moz-linear-gradient(top, #f3f3f3, #d1d1d1);
    background-image: -ms-linear-gradient(top, #f3f3f3, #d1d1d1);
    background-image: -o-linear-gradient(top, #f3f3f3, #d1d1d1);
    background-image: linear-gradient(top, #f3f3f3, #d1d1d1);
    border-top: 1px solid hsl(0, 0%, 68%);
    border-right: 1px solid hsl(0, 0%, 62%);
    border-bottom: 1px solid hsl(0, 0%, 52%);
    border-left: 1px solid hsl(0, 0%, 62%);
    -webkit-box-shadow: inset 0 1px 0 0 #d9d9d9;
    box-shadow: inset 0 1px 0 0 #d9d9d9;
    cursor: pointer;
    color: #334;
    }
  .button:active {
    border: 1px solid #858585;
    -webkit-box-shadow: inset 0 0 8px 2px #d1d1d1, 0 1px 0 0 #eeeeee;
    box-shadow: inset 0 0 8px 2px #d1d1d1, 0 1px 0 0 #eeeeee;
    }
  .button.disabled {
    color: #888;
    }



.button.icon-add,
.button.icon-apply,
.button.icon-apply_preview,
.button.icon-back,
.button.icon-delete,
.button.icon-remove,
.button.icon-search,
.button.icon-markup{
    padding-left: 32px;
    }
.button.icon-twitter,
.button.icon-change{
    padding-left: 29px;
    }

    .button.icon-add:before,
    .button.icon-apply:before,
    .button.icon-apply_preview:before,
    .button.icon-back:before,
    .button.icon-delete:before,
    .button.icon-remove:before,
    .button.icon-search:before,
    .button.icon-markup:before,
    .button.icon-twitter:before,
    .button.icon-change:before{
        background-repeat: no-repeat;
        background-position: 0px -1px;
        position: absolute;
        top: 4px;
        left: 10px;
        width: 22px;
        height: 22px;
        content: "";
        }

    .button.icon-add:before{
        background-image: url(../images/actions/add.png);
    }

    .button.icon-apply:before{
        background-image: url(../images/actions/apply.png);
    }

    .button.icon-apply_preview:before{
        background-image: url(../images/actions/apply_preview.png);
    }

    .button.icon-back:before{
        background-image: url(../images/actions/back.png);
    }

    .button.icon-delete:before{
        background-image: url(../images/actions/delete.png);
    }

    .button.icon-remove:before{
        background-image: url(../images/actions/remove.png);
    }

    .button.icon-search:before{
        background-image: url(../images/actions/search.png);
    }

    .button.icon-markup:before{
        background-image: url(../images/actions/markup.png);
    }

    .button.icon-twitter:before{
        background-image: url(../images/actions/twitter.png);
    }

    .button.icon-change:before{
        background-image: url(../images/actions/change.png);
    }

.form-controls .button{
  vertical-align: top;
    margin-left: 15px;
    }
.button.action-delete{
    margin-right: 50px;
    }

.button.active{
    background-image: -webkit-gradient(linear, left bottom, left top, color-stop(0%, #f3f3f3), color-stop(100%, #d1d1d1));
    background-image: -webkit-linear-gradient(bottom, #f3f3f3, #d1d1d1);
    background-image: -moz-linear-gradient(bottom, #f3f3f3, #d1d1d1);
    background-image: -ms-linear-gradient(bottom, #f3f3f3, #d1d1d1);
    background-image: -o-linear-gradient(bottom, #f3f3f3, #d1d1d1);
    background-image: linear-gradient(bottom, #f3f3f3, #d1d1d1);
    background-image: linear-gradient(top, #f3f3f3, #d1d1d1);
    border-top: 1px solid hsl(219, 20%, 68%);
    border-right: 1px solid hsl(219, 20%, 62%);
    border-bottom: 1px solid hsl(219, 20%, 52%);
    border-left: 1px solid hsl(219, 20%, 62%);
    box-shadow: inset 0 1px 5px 0 hsl(219, 60%, 70%);
    }
