.popup-select{
    position:relative;
}
.popup-select .selected_values {
  list-style-type:none;
  padding:0px;
  }
  .popup-select .selected_values li{
    display:none;
    margin:3px 0px;
    }

  .popup-select .selected_values li.selected{
    display:block;
    }

  .popup-select .selected_values label{
    padding: 0 5px;
    display: inline;
    -moz-border-radius-topleft: 3px;
    -moz-border-radius-bottomleft: 3px;
    background:#CCCCCC none repeat scroll 0% 0%;
    text-shadow: 1px 0 #fff;
    margin:0px;
    }

  .selected_values label.published {
    background:#CAECC7 none repeat scroll 0% 0%;
    }

  .popup-select .selected_values span {
    border-left:1px solid #ffffff;
    color:ffffff;
    padding:0 5px;
    margin:0px;
    cursor:pointer;
    -moz-border-radius-topright: 3px;
    -moz-border-radius-bottomright: 3px;
    background:#CCCCCC none repeat scroll 0% 0%;
    }

  .popup-select .selected_values input {
    display:none;
    }

.filter-list-value {
  -moz-border-radius:5px;
  cursor:pointer;
  padding:3px 5px;
  margin-bottom:3px;
  border:1px solid #EBE9E3;
  }
  .filter-list-value.hover {
    border: 1px solid #65A12B
    }

  .filter-list-value.published {
    color:#218211;
    }

  .filter-list-value.selected {
    background:#CCCCCC none repeat scroll 0% 0%;	
    }

  .filter-list-value.disabled {
    cursor: default;
    }

.filter-list-popup {
  min-width:600px;
  }

.search_label {
  margin-right:10px;
  }

.right_round {
    -moz-border-radius-topright: 3px;
    -moz-border-radius-bottomright: 3px;
}


