<div class="init-block label-select"
     data-block-name="label-select"
     {% if widget.multiple %} data-multiple="multiple"{% endif %}>
    <table>
      <tr>
        {% for option in options %}
          {% if option.value not in widget.hiddens or option.selected %}
            <td>
              <label class="label-select__option{% if option.selected %} selected{% endif %}"
                     for="{{ widget.id }}-{{option.value|escape}}">
                <input type="{{ 'checkbox' if widget.multiple else 'radio' }}"
                       id="{{ widget.id }}-{{option.value|escape}}"
                       name="{{ widget.input_name }}"
                       value="{{ option.value|escape }}"
                       {% if option.selected %} checked="checked"{% endif %}
                       style="display: none" />
                {{ option.title|escape }}
              </label>
            </td>
          {% endif %}
        {% endfor %}
      </tr>
    </table>
</div>
