<table class="fieldlist init-block{% if widget.classname %} {{ widget.classname }}{% endif %}" id="{{ field.id }}"
       data-input-name="{{ field.input_name }}"
       data-block-name="fieldlist"
       data-new-block-position="{{widget.new_block_position or ''}}"
       data-template="{{ widget.render_template_field()|forceescape }}"
       {%- if widget.allow_create %}data-allowcreate="allowcreate"{% endif -%}
       {%- if widget.allow_delete %}data-allowdelete="allowdelete"{% endif -%}
       {%- if readonly %} data-readonly="readonly"{% endif %}
       {%- if field.order %} data-order="true"{% endif %}
       {%- if field.max_length %} data-max-length="{{ field.max_length }}"{% endif -%}
       >
    <tbody>
    {% for index in field.form.raw_data.getall(field.indices_input_name) %}
        <tr class="fieldlist-item">
            <td class="fieldlist-cell">
                <input type="hidden" name="{{ field.indices_input_name }}" value="{{ index }}" />
                {% set f = field.field(name=index) %}
                {% if f.error %}
                <div>
                  <span class="error">{{ f.error }}</span>
                </div>
                {% endif %}
                {{ f.widget.render() }}
            </td>
            {% if field.order %}
            <td class="fieldlist-order fieldlist-btns"></td>
            {% endif %}
            <td class="fieldlist-delete fieldlist-btns"></td>
        </tr>
    {% endfor %}
    </tbody>
</table>
