<textarea id="{{ widget.id }}" name="{{ widget.input_name }}"
          {%- if readonly %} readonly="readonly"{% endif %}
          class="init-block{% if widget.classname %} {{ widget.classname }}{% endif %}"
          data-block-name="textarea">
  {{- value|escape -}}
</textarea>

