.wysihtml5-widget{
    width: 600px;
    }
textarea.wysihtml5{
  height: 400px;
  max-width: 600px;
  }

.wysihtml5-toolbar {
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif !important;
  position: relative;
  margin: 0;
  padding: 0;
  padding-left: 2px;
  /*line-height: 0;
  font-size: 0;*/
  background: #f1f1f1;
  background: -moz-linear-gradient(top,  #f1f1f1 0%, #e2e2e2 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f1f1f1), color-stop(100%,#e2e2e2));
  background: -webkit-linear-gradient(top,  #f1f1f1 0%,#e2e2e2 100%);
  background: -o-linear-gradient(top,  #f1f1f1 0%,#e2e2e2 100%);
  background: -ms-linear-gradient(top,  #f1f1f1 0%,#e2e2e2 100%);
  background: linear-gradient(to bottom,  #f1f1f1 0%,#e2e2e2 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f1f1f1', endColorstr='#e2e2e2',GradientType=0 );
  /*height: 32px !important;*/
  border-bottom: 1px solid #bbb;
  }
  .wysihtml5-toolbar a.btn {
    display: block;
    float: left;
    margin: 0;
    padding: 3px 1px;
    padding-right: 0;
    outline: none;

    width: 25px;
    height: 25px;
    border: 1px solid transparent;
    line-height: 0;
    font-size: 0;
    cursor: pointer;
    text-decoration: none;
    }
  .wysihtml5-toolbar a.btn:hover {
    border-color: #98a6ba;
    background-color: #dde4ef;
    outline: none;
    }
  .wysihtml5-toolbar a.btn:active,
  .wysihtml5-toolbar a.btn.wysihtml5-action-active,
  .wysihtml5-toolbar a.btn.wysihtml5-command-active {
    border-color: #b5b5b5;
    background-color: #ddd;
    outline: none;
    }
  .wysihtml5-commands-disabled a.btn[data-wysihtml5-command],
  .wysihtml5-toolbar a.btn.disabled{
    border-color: transparent;
    background-color: transparent;
    opacity: 0.5;
    cursor: default;
    }

.wysihtml5-toolbar .separator {
  float: left;
  height: 34px;
  border-left: 1px solid #d3d3d3;
  border-right: 1px solid #f1f1f1;
  padding: 0;
  margin: 0 2px 0 3px !important;
  }
  .wysihtml5-toolbar .separator+.separator {
    clear: both;
    float: none;
    width: 100%;
    height: 0;
    margin: 0 !important;
    border: none;
    border-top: 1px solid #d3d3d3;
    border-bottom: 1px solid #f1f1f1;
    }

/* XXX these styles are not free, rewrite them */

/* buttons */
.wysihtml5-toolbar a.btn {
  background-image: url(../images/redactor_2x.png);
  background-repeat: no-repeat;
  background-position: 0;
  background-size: 1250px;
  }

.wysihtml5-toolbar a.btn[data-wysihtml5-command="bold"] { background-position: -50px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="italic"] { background-position: -75px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="insertunorderedlist"] { background-position: -100px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="insertorderedlist"] { background-position: -125px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="outdent"] { background-position: -150px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="indent"] { background-position: -175px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="insertImage"] { background-position: -200px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="table"] { background-position: -275px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="createLink"] { background-position: -300px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="underline"] { background-position: -525px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="fullscreen"] { background-position: -550px; }
.fullscreen .wysihtml5-toolbar a.btn[data-wysihtml5-command="fullscreen"] { background-position: -575px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="sup"] { background-position: -650px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="sub"] { background-position: -675px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="extrachars"] { background-position: -700px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="fileLink"] { background-position: -725px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="blockquote"] { background-position: -750px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="headings"] { background-position: -775px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="personLink"] { background-position: -800px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="undo"] { background-position: -825px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="redo"] { background-position: -850px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="termLink"] { background-position: -875px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="supplementLink"] { background-position: -900px; }
.wysihtml5-toolbar a.btn[data-wysihtml5-command="docLink"] { background-position: -925px; }
.wysihtml5-menu a[data-wysihtml5-command="h1"] { font-size: 1.4em; }
.wysihtml5-menu a[data-wysihtml5-command="h2"] { font-size: 1.3em; }
.wysihtml5-menu a[data-wysihtml5-command="h3"] { font-size: 1.2em; }
.wysihtml5-menu a[data-wysihtml5-command="h4"] { font-size: 1.1em; }

.wysihtml5-toolbar a { cursor: pointer; border-bottom: 1px dotted #888; text-decoration: none; }

.wysihtml5-dialog-place{
  float: left;
  position: relative;
  }
.wysihtml5-dialog{
  position: absolute;
  min-width: 34px;
  line-height: 34px;
  top: 34px;
  padding: 3px;
  max-width: 600px;
  background: rgba(250, 250, 250, 0.95);
  border: 1px solid #aaa;
  border-radius: 3px;
  }
  .wysihtml5-dialog-place .wysihtml5-dialog{
    left: -40px;
    }
  .wysihtml5-menu a{
    display: block;
    white-space: nowrap;
    border: none;
    line-height: 1em;
    padding: 6px;
    margin: 6px 0;
    border: 1px solid transparent;
    }
    .wysihtml5-menu a.wysihtml5-command-active{
      background: #ddd;
      border-color: #b5b5b5;
    }
    .wysihtml5-menu a:hover{
      background: #dde4ef;
      /*border-color: #98a6ba;*/
      }

.wysihtml5-char{
  text-decoration: none;
  display: block;
  float: left;
  font-size: 15px;
  line-height: 15px;
  margin: 0 5px 0 0;
  padding: 5px;
  border: 1px solid transparent;
  }


  .wysihtml5-char:hover {
    background-color: #dde4ef;
    border-color: #98a6ba;
    background-color: #dde4ef;
    }


.wysihtml5-widget.tiny textarea.wysihtml5{
  height: 100px;
  }
.wysihtml5-widget.long textarea.wysihtml5{
  height: 600px;
  }
.wysihtml5-widget.shallow {
  width: 300px;
  }
  .wysihtml5-widget.shallow textarea.wysihtml5{
    width: 300px;
    height: 300px;
    }

.wysihtml5-widget.fullscreen{
    position: fixed;
    top: 0;
    z-index: 4;
    left:  0;
    bottom:  35px; /* hack to make iframe 100% equal to window 100%-35px */
    right: 0;
    width: auto;
    background: #fff;
    }
.wysihtml5-widget.fullscreen iframe,
.wysihtml5-widget.fullscreen textarea{
    position: absolute;
    top: 35px !important;
    left: 0 !important; bottom: 0 !important; right: 0!important;
    width: 100% !important;
    height: 100% !important;
    max-width: inherit !important;
}
body.wysihtml5-fullscreen{
    overflow: hidden;
    }
