/* Calendar: a Javascript class for Mootools that adds accessible and unobtrusive date pickers to your form elements <http://electricprism.com/aeron/calendar> */
/* Dashboard CSS for Calendar (navigation: 1), Copyright (c) 2007 Aeron Glemann <http://electricprism.com/aeron> */

input.calendar {
    width: 100px;
}
input.timeinput {
    width: 60px;
}

select.calendar {
    width: 149px;
}

button.calendar {
    background: url(../images/calendar-icon.gif);
    border: 0;
    cursor: pointer;
    height: 20px;
    width: 20px;
    display: inline-block;
    margin-left: 5px;
    vertical-align: middle;
}
}
button.calendar:hover,
button.calendar.active {
    background-position: 0 20px;
}

div.calendar {
    background: url(../images/calendar.png);
    height: 175px;
    padding: 0 12px;
    text-align: center;
    width: 147px;
}
    div.calendar * {
        margin: 0;
        padding: 0;
    }
    div.calendar div {
        background: none !important;
        cursor: move;
        height: 165px;
        overflow: hidden;
        padding-top: 10px;
        position: relative;
        width: 147px;
    }

    div.calendar caption {
        color: #CF0;
        font: normal 12px/17px Arial, Helvetica, sans-serif;
        padding-top: 4px;
        text-align: center;
        width: 100%;
    }
    div.calendar caption a {
        cursor: pointer;
        display: block;
        height: 11px;
        overflow: hidden;
        position: absolute;
        text-indent: -100px;
        top: 16px;
        width: 11px;
    }
    div.calendar caption a.prev {
        background-image: url(../images/calendar-prev.gif);
        left: 1px;
    }
    div.calendar caption a.next {
        background-image: url(../images/calendar-next.gif);
        right: 1px;
    }
    div.calendar caption a:hover {
        background-position: 0 11px;
    }
    div.calendar caption span {
        height: 25px;
        position: relative;
        text-align: center;
    }
    div.calendar caption span.month {
        padding-right: 8px;
    }
    div.calendar caption span.month:after {
        content: ',';
    }

    div.calendar table {
        border: 0;
        border-collapse: collapse;
        border-spacing: 0;
        cursor: default;
        margin: 0 auto;
        overflow: hidden;
        width: 147px;
    }
    div.calendar td,
    div.calendar th {
        border: 0;
        color: #999;
        font: normal 12px Arial, Helvetica, sans-serif;
        height: 19px;
        text-align: center;
        width: 21px;
    }
    div.calendar td {
        color: #333;
        font-size: 11px;
        padding-right: 5px;
        text-align: right;
        width: 16px;
    }
    div.calendar td.invalid {
        color: #666;
    }
    div.calendar td.valid {
        color: #FFF;
        cursor: pointer;
    }
    div.calendar td.active,
    div.calendar td.hover {
        color: #CF0;
        cursor: pointer;
    }
